# getCF
[![Apache License](https://img.shields.io/badge/License-DWTFYW-green.svg)](https://github.com/andreasala98/getCF/blob/master/LICENSE)


A simple exercise to retrieve the Italian Fiscal Code in python3.
### Installation
Execute the following (possibly in a virtual environment):
```bash
git clone git@github.com:andreasala98/getYourCF.git
cd getYourCF
sudo pip3 install -e .
```

### Usage
- Command Line Usage:
```bash
getcf
```
and then follow instructions

- Input file usage:
```bash
getcf -i <path_to_file>
```
The program automatically recongnizes a json from other file formats. Example input files can be found [here](https://github.com/andreasala98/getCF/blob/master/data/example.json) and [here](https://github.com/andreasala98/getCF/blob/master/data/example.txt)

### Documentation
Not ready yet, even though the docs website is up and running

### Contribute
Please raise issues or contact me or Matteo for any major bug


Work in progress... sometimes...
